pub enum LogFieldValue {
Mapping(HashMap<String, LogFieldValue>),
Timestamp(DateTime<FixedOffset>),
Text(String),
Int(u64),
}Expand description
Possible types of values for a single log field.
Values may be nested arbitrarily deep by using the Mapping variant.
This is typically used for groups of values like request or response
headers.
Variants